@@ -5,10 +5,9 @@ use warnings;
 package Object::Adhoc;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.003';
+our $VERSION   = '0.004';
 
-use Hash::Util qw(lock_ref_keys);
-use Digest::MD5 qw(md5_hex);
+use Digest::MD5 qw( md5_hex );
 use Exporter::Shiny qw( object make_class );
 our @EXPORT = qw( object );
 
@@ -18,6 +17,12 @@ BEGIN {
 		: sub () { !!0 };
 };
 
+BEGIN {
+	require Hash::Util;
+	*lock_ref_keys = 'Hash::Util'->can('lock_ref_keys')
+		|| sub { return; };
+};
+
 our $RESERVED_REGEXP;
 
 # Yes, you can push extra methods onto this array if you need to,
@@ -87,7 +92,7 @@ sub make_class {
 		my $code = "package $class;\n";
 		while (my ($predicate, $key) = each %predicates) {
 			my $qkey = B::perlstring($key);
-			$code .= "sub $predicate :method { &Object::Adhoc::_usage if \@_ > 1; exists \$_[0]{$qkey} }\n";
+			$code .= "sub $predicate :method { &Object::Adhoc::_usage if \@_ > 1; CORE::exists \$_[0]{$qkey} }\n";
 		}
 		while (my ($getter, $key) = each %getters) {
 			my $qkey = B::perlstring($key);
